<?php
/**
 * @ H2N Link Directory 1.0.0 linkdirectory.captcha.php
 * @ Copyright (C) 2008 Harry Klein - www.joomla-hklein.de
 * @
 * @ All rights reserved
 * @ Link Directory Component is Free Software
 * @ Released under GNU/GPL License : http://www.gnu.org/copyleft/gpl.html
 * @
 * @ $Id: linkdirectory.captcha.php,v 1.10 2009/04/26 20:49:40 harry Exp $
 * @
 **/

defined( '_VALID_MOS' ) or die( 'Restricted access' );

/**
 * Überprüft das eingegebene Captcha und liefert bei richtiger Eingabe true zurück.
 *
 * @return true, wenn Catcha richtig eingegeben worden ist oder kein Catcha-Dienst konfiguriert ist.
 * @see #isCaptchaEnable()
 */
function validateCaptcha (){
	global $ld;
	
	if (!isCaptchaEnable()) return true;
	
	$checkSecurity = false;
	switch($ld->securityimage) {
		case 'easycaptcha':
			$captcha_id = strval( mosGetParam( $_POST, 'captcha_id', '' ) );
			$captcha_code = strval( mosGetParam( $_POST, 'captcha_code', '' ) );
			$captcha = new EasyCaptcha($captcha_id);
			$checkSecurity = $captcha->checkEnteredCode($captcha_code);
			break;
		case 'securityimages5':
			$userEntry = JRequest::getVar('securityImagesmy3rdpartyExtensions', false, '', 'CMD'); 
			global $mainframe;
			$mainframe->triggerEvent('onSecurityImagesCheck', array($userEntry, &$check));
			$checkSecurity = $check;
			break;
		case 'securityimages4':
			require_once _LD_ABSOLUTE_PATH.'/administrator/components/com_securityimages/server.php';
			$securityimage_newpass_refid = mosGetParam( $_POST, 'securityimage_newpass_refid','');
			$securityimage_newpass_try = mosGetParam( $_POST, 'securityimage_newpass_try','');
			$securityimage_newpass_reload = mosGetParam( $_POST, 'securityimage_newpass_reload','');
			$checkSecurity = checkSecurityImage($securityimage_newpass_refid, $securityimage_newpass_try,
			$securityimage_newpass_reload);
			break;
		case 'securityimages3':
			require_once _LD_ABSOLUTE_PATH.'/administrator/components/com_securityimages/server.php';
			$security_refid = mosGetParam($_POST, "security_refid", $security_refid);
			$security_try = mosGetParam($_POST, "security_try", $security_try);
			$checkSecurity = checkSecurityImage($security_refid, $security_try);
			break;
		default:
			$checkSecurity = true;
	}
	return $checkSecurity;
}

/**
 * Liefert true, wenn Captcha angezeigt werden soll. Es ist abhänig davon, ob<ul>
 *   <li>ein entsprechender Dienst verfügbar und konfiguriert ist,</li>
 *   <li>der User angemeldt ist und</li>
 *   <li>Capatche nur für annonyme User angezeigt werden soll.</li>
 * </ul>   
 *
 * @return true, wenn Captcha angezeigt werden soll.
 * @see $ld->securityimageonlyforannonymous
 */
function isCaptchaEnable(){
	global $ld,$my;
	switch($ld->securityimage) {
		case 'easycaptcha':
			if (file_exists(_LD_ABSOLUTE_PATH.'/components/com_easycaptcha/class.easycaptcha.php')) {
      			include_once(_LD_ABSOLUTE_PATH.'/components/com_easycaptcha/class.easycaptcha.php');
      			if(class_exists("EasyCaptcha") AND ( !$my->gid OR ! $ld->securityimageonlyforannonymous )){
					return true;
      			}
			}
			break;
		case 'securityimages5':
			if (file_exists(_LD_ABSOLUTE_PATH.'/administrator/components/com_securityimages/config.securityimages.php')){
				global $securitySwitchOffGlobally;
				if (!$securitySwitchOffGlobally AND ( !$my->gid OR ! $ld->securityimageonlyforannonymous )){
					return true;
				}
			}
			break;
		case 'securityimages3':
		case 'securityimages4':
			if (file_exists(_LD_ABSOLUTE_PATH.'/administrator/components/com_securityimages/config.securityimages.php') &&
				file_exists(_LD_ABSOLUTE_PATH.'/administrator/components/com_securityimages/client.php')){
				global $securitySwitchOffGlobally;
				if (!$securitySwitchOffGlobally AND ( !$my->gid OR ! $ld->securityimageonlyforannonymous )){
					return true;
				}	
			}
			break;
	}
	return false;
}

/**
 * Gibt das HTML für die Anzeige des konfigurierten Captcha zurück.
 *
 * @return HTML für die Anzeige des konfigurierten Captcha zurück.
 * @see #isCaptchaEnable()
 */
function displayCaptcha (){
	if (!isCaptchaEnable()) return '';
	global $ld;
	$html='';
	switch($ld->securityimage) {
		case 'easycaptcha':
			$captcha = new easyCaptcha();
			if($captcha->captcha_id) {
				$html.='<input type="hidden" name="captcha_id" value="';
				$html.=$captcha->getCaptchaId() . '" />';
				$html.='<img src="';
				$html.=$captcha->getImageUrl();
				$html.=' alt="'.$captcha->getAltText();
				$html.='" id="code" />'.$captcha->getReloadButton("code").$captcha->getReloadCode();
				$html.='<br />';
				$html.='<br />';
				$html.='<input type="text" name="captcha_code" id="contact_captcha" class="inputbox" />';
			}
			break;
		case 'securityimages5':
			?>
			<script type="text/javascript" src="components/com_securityimages/js/securityImages.js"></script>
			<input type="text" 
			 name="securityImagesmy3rdpartyExtensions"  align="middle" />&nbsp;
			<img id='captchaSecurityImages' name='captchaSecurityImages' 
			     src="index.php?option=com_securityimages&task=displaycaptcha" align="middle">&nbsp;<a href="javascript:askNewSecurityImages('captchaSecurityImages');"><img 
			 src="components/com_securityimages/buttons/reload.gif" id="securityImagesContactCaptchaReload" 
			 name="securityImagesContactCaptchaReload" border="0" align="middle"></a><?php
			break;
		case 'securityimages4':
			require_once _LD_ABSOLUTE_PATH.'/administrator/components/com_securityimages/client.php';
			$packageName = 'securityimage_newpass';
			$html.=insertSecurityImage($packageName);
			$html.='<br />';
			$html.=getSecurityImageField($packageName);
			break;
		case 'securityimages3':
			require_once _LD_ABSOLUTE_PATH.'/administrator/components/com_securityimages/client.php';
			$html.=insertSecurityImage("security_refid");
			$html.='<br>';
			$html.=getSecurityImageText("security_try");
			break;
		default:
			$html='';
	}
	return $html;
}

/**
 * Liefert ein Array ('value','text') mit den verfügbaren Catcha-Diensten zurück.
 *
 * @return Array mit den Verfügbaren Captcha-Diensten 
 */
function &getAvailableCapatchServices(){
	$capcha = array();
	$capcha[] = mosHTML::makeOption( 'none', _LD_SEC_IMAGE_NONE );
	
	if (@file_exists(_LD_ABSOLUTE_PATH.'/administrator/components/com_securityimages/config.securityimages.php')){
		global $securityImagesVersionShort;
		require _LD_ABSOLUTE_PATH.'/administrator/components/com_securityimages/config.securityimages.php';
		list ($major,$minor, $patch) = split('[.]', $securityImagesVersionShort,3);
		if( defined('_JEXEC') ){
			if ($major >= 5) {
				$capcha[] = mosHTML::makeOption( 'securityimages5', 'Security Images 5.x' );
			}
		} else {
			if ($major == 4) {
				$capcha[] = mosHTML::makeOption( 'securityimages4', 'Security Images 4.x' );
			}	
			if ($major == 3) {
				$capcha[] = mosHTML::makeOption( 'securityimages3', 'Security Images 3.x' );
			}
		}
		
	}
	if(file_exists(_LD_ABSOLUTE_PATH.'/components/com_easycaptcha/class.easycaptcha.php')) {
		$capcha[] = mosHTML::makeOption( 'easycaptcha', 'Easy Captcha' );
	}
	return $capcha;
}

?>